import { createUser } from '#src/api/index.js';
import {
  generateUsername,
  generateEmail,
  generatePhone,
  generatePassword,
  generateName,
} from '#src/utils.js';

export type NewUserProfileOptions = {
  username?: true;
  password?: true;
  name?: true;
  primaryEmail?: true;
  primaryPhone?: true;
};

export const generateNewUserProfile = <T extends NewUserProfileOptions>({
  username,
  password,
  name,
  primaryEmail,
  primaryPhone,
}: T) => {
  type UserProfile = {
    [K in keyof T]: T[K] extends true ? string : never;
  };

  // @ts-expect-error - TS can't map the type of userProfile to the UserProfile defined above
  const userProfile: UserProfile = {
    name: generateName(),
    ...(username ? { username: generateUsername() } : {}),
    ...(password ? { password: generatePassword() } : {}),
    ...(name ? { name: generateName() } : {}),
    ...(primaryEmail ? { primaryEmail: generateEmail() } : {}),
    ...(primaryPhone ? { primaryPhone: generatePhone() } : {}),
  };

  return userProfile;
};

export const generateNewUser = async <T extends NewUserProfileOptions>(options: T) => {
  const userProfile = generateNewUserProfile(options);

  const user = await createUser(userProfile);

  return { user, userProfile };
};
